@@ -12,20 +12,17 @@
 #include "core/kget.h"
 
 #include <KLocalizedString>
-#include <KPluginInfo>
 #include <KSharedConfig>
 #include <QDialog>
+#include <KSharedConfig>
+#include <KConfigGroup>
+
 
 PluginSelector::PluginSelector(QDialog * parent)
-  : KPluginSelector(parent)
+  : KPluginWidget(parent)
 {
-    KPluginInfo::List offers = KGet::self()->pluginInfos();
-
-
-    addPlugins(offers, KPluginSelector::ReadConfigFile, i18n("Plugins"), "Service", KSharedConfig::openConfig());
-
-    
-    load();
+    setConfig(KConfigGroup(KSharedConfig::openConfig(), "Plugins"));
+    addPlugins(KGet::self()->plugins(), i18n("Plugins"));
 
     connect(parent, &QDialog::accepted, this, &PluginSelector::saveState);
     connect(parent, &QDialog::rejected, this, &PluginSelector::loadDefaults);
