@@ -53,22 +53,22 @@ void Download::slotResult(KJob * job)
                 //TODO: Do a Message box here
             torrentFile.write(m_data);
             torrentFile.close();
-            emit finishedSuccessfully(m_destUrl, m_data);
-            m_data = 0;
+            Q_EMIT finishedSuccessfully(m_destUrl, m_data);
+            m_data = nullptr;
             break;
         }
         case KIO::ERR_FILE_ALREADY_EXIST:
         {
             qCDebug(KGET_DEBUG) << "ERROR - File already exists";
             QFile file(m_destUrl.toLocalFile());
-            emit finishedSuccessfully(m_destUrl, file.readAll());
-            m_data = 0;
+            Q_EMIT finishedSuccessfully(m_destUrl, file.readAll());
+            m_data = nullptr;
             break;
         }
         default:
             qCDebug(KGET_DEBUG) << "We are sorry to say you, that there were errors while downloading :(";
-            m_data = 0;
-            emit finishedWithError();
+            m_data = nullptr;
+            Q_EMIT finishedWithError();
             break;
     }
 }
