@@ -31,12 +31,12 @@ class KGET_EXPORT Download : public QObject
         void finishedSuccessfully(QUrl dest, QByteArray data);
         void finishedWithError();
 
-    private slots:
+    private Q_SLOTS:
         void slotResult(KJob * job);
         void slotData(KIO::Job *job, const QByteArray& data);
 
     private:
-        KIO::TransferJob *m_copyJob;
+        KIO::TransferJob *m_copyJob = nullptr;
         QUrl m_srcUrl;
         QUrl m_destUrl;
         QUrl m_destFile;
