@@ -17,26 +17,24 @@
 #include "core/plugin/transferfactory.h"
 #include "core/scheduler.h"
 
-#include <KIconLoader>
 #include <KLocalizedString>
-
+#include <KLazyLocalizedString>
 #include <QDomElement>
 #include <QTime>
 
 struct StatusStrings
 {
-    const char * context;
-    const char * name;
+    KLazyLocalizedString name;
 };
 
 const StatusStrings STATUSTEXTS[] = {
-    {"", I18N_NOOP("Downloading....")},
-    {I18NC_NOOP("transfer state: delayed", "Delayed")},
-    {I18NC_NOOP("transfer state: stopped", "Stopped")},
-    {I18NC_NOOP("transfer state: aborted", "Aborted")},
-    {I18NC_NOOP("transfer state: finished", "Finished")},
-    {"", ""},//TODO: Add FinishedKeepAlive status
-    {I18NC_NOOP("changing the destination of the file", "Changing destination")}
+    {kli18n("Downloading....")},
+    {kli18nc("transfer state: delayed", "Delayed")},
+    {kli18nc("transfer state: stopped", "Stopped")},
+    {kli18nc("transfer state: aborted", "Aborted")},
+    {kli18nc("transfer state: finished", "Finished")},
+    {KLazyLocalizedString()},//TODO: Add FinishedKeepAlive status
+    {kli18nc("changing the destination of the file", "Changing destination")}
 };
 const QStringList STATUSICONS = QStringList() << "media-playback-start" << "view-history" << "process-stop" << "dialog-error" << "dialog-ok" << "media-playback-start" << "media-playback-pause";
 
@@ -178,7 +176,7 @@ void Transfer::checkShareRatio()
     if (m_downloadedSize == 0 || m_ratio == 0)
         return;
 
-    if (m_uploadedSize / m_downloadedSize >= m_ratio)
+    if ((double)m_uploadedSize / m_downloadedSize >= m_ratio)
         setDownloadLimit(1, Transfer::InvisibleSpeedLimit);//If we set it to 0 we would have no limit xD
     else
         setDownloadLimit(0, Transfer::InvisibleSpeedLimit);
@@ -231,7 +229,7 @@ void Transfer::load(const QDomElement *element)
 {
     if (!element)
     {
-        setStatus(status(), i18nc("transfer state: stopped", "Stopped"), SmallIcon("process-stop"));
+        setStatus(status(), i18nc("transfer state: stopped", "Stopped"), "process-stop");
         setStartStatus(status());
         return;
     }
@@ -250,7 +248,7 @@ void Transfer::load(const QDomElement *element)
         setStartStatus(Job::Finished);
         setStatus(startStatus());
     } else {
-        setStatus(status(), i18nc("transfer state: stopped", "Stopped"), SmallIcon("process-stop"));
+        setStatus(status(), i18nc("transfer state: stopped", "Stopped"), "process-stop");
         setStartStatus(status());
     }
     setUploadLimit(e.attribute("UploadLimit").toInt(), Transfer::VisibleSpeedLimit);
@@ -275,19 +273,19 @@ void Transfer::load(const QDomElement *element)
     }
 }
 
-void Transfer::setStatus(Job::Status jobStatus, const QString &text, const QPixmap &pix)
+void Transfer::setStatus(Job::Status jobStatus, const QString &text, const QString &pix)
 {
     const bool statusChanged = (status() != jobStatus);
     QString statusText = text;
     if (statusText.isEmpty()) {
-        statusText = i18nc(STATUSTEXTS[jobStatus].context, STATUSTEXTS[jobStatus].name);
+        statusText = KLocalizedString(STATUSTEXTS[jobStatus].name).toString();
     }
 
     //always prefer pix, if it is set
     if (!pix.isNull()) {
-        m_statusPixmap = pix;
-    } else if (statusChanged || m_statusPixmap.isNull()) {
-        m_statusPixmap = SmallIcon(STATUSICONS[jobStatus]);
+        m_statusIconName = pix;
+    } else if (statusChanged || m_statusIconName.isNull()) {
+        m_statusIconName = STATUSICONS[jobStatus];
     }
 
     m_statusText = statusText;
@@ -324,10 +322,10 @@ void Transfer::setTransferChange(ChangesFlags change, bool postEvent)
 
 QString Transfer::statusText(Job::Status status)
 {
-    return i18nc(STATUSTEXTS[status].context, STATUSTEXTS[status].name);
+    return STATUSTEXTS[status].name.toString();
 }
 
-QPixmap Transfer::statusPixmap(Job::Status status)
+QString Transfer::statusIconName(Job::Status status)
 {
-    return SmallIcon(STATUSICONS[status]);
+    return STATUSICONS[status];
 }
