@@ -36,7 +36,7 @@ TransferHandler::TransferHandler(Transfer * parent, Scheduler * scheduler)
 
     m_kjobAdapter = new KGetKJobAdapter(this, this);
 
-    connect(m_transfer, SIGNAL(capabilitiesChanged()), this, SIGNAL(capabilitiesChanged()));
+    connect(m_transfer, &Transfer::capabilitiesChanged, this, &TransferHandler::capabilitiesChanged);
 }
 
 TransferHandler::~TransferHandler()
@@ -160,7 +160,7 @@ QVariant TransferHandler::data(int column)
 
 void TransferHandler::setSelected( bool select )
 {
-    if( (select && !isSelected()) || (!select && isSelected()) )
+    if (select != isSelected())
     {
         m_transfer->m_isSelected = select;
         setTransferChange( Transfer::Tc_Selection, true );
