@@ -114,7 +114,7 @@ QVariant TransferModelItem::data(int role) const
                 return m_mimeType;
             }
             case 1:
-                return m_transferHandler->statusPixmap();
+                return QIcon::fromTheme(m_transferHandler->statusIconName());
         }
     }
     if (role == Qt::TextAlignmentRole)
@@ -215,7 +215,7 @@ void TransferTreeModel::addGroup(TransferGroup * group)
 
     m_transferGroups.append(static_cast<GroupModelItem*>(items.first()));
 
-    emit groupAddedEvent(group->handler());
+    Q_EMIT groupAddedEvent(group->handler());
 
     KGet::m_scheduler->addQueue(group);
 }
@@ -242,7 +242,7 @@ void TransferTreeModel::delGroup(TransferGroup * group)
 
     m_changedGroups.removeAll(group->handler());
 
-    emit groupRemovedEvent(group->handler());
+    Q_EMIT groupRemovedEvent(group->handler());
 
     KGet::m_scheduler->delQueue(group);
 }
@@ -273,7 +273,7 @@ void TransferTreeModel::addTransfers(const QList<Transfer*> &transfers, Transfer
 
         m_transfers.append(static_cast<TransferModelItem*>(items.first()));
 
-        DBusTransferWrapper * wrapper = new DBusTransferWrapper(handler);
+        auto * wrapper = new DBusTransferWrapper(handler);
         new TransferAdaptor(wrapper);
         QDBusConnection::sessionBus().registerObject(handler->dBusObjectPath(), wrapper);
     }
@@ -281,7 +281,7 @@ void TransferTreeModel::addTransfers(const QList<Transfer*> &transfers, Transfer
     //notify the rest of the changes
     blockSignals(false);
     endInsertRows();
-    emit transfersAddedEvent(handlers);
+    Q_EMIT transfersAddedEvent(handlers);
 }
 
 void TransferTreeModel::delTransfers(const QList<Transfer*> &t)
@@ -308,7 +308,7 @@ void TransferTreeModel::delTransfers(const QList<Transfer*> &t)
         }
     }
 
-    emit transfersAboutToBeRemovedEvent(handlers);
+    Q_EMIT transfersAboutToBeRemovedEvent(handlers);
 
     //remove the items from the model
     {
@@ -359,7 +359,7 @@ void TransferTreeModel::delTransfers(const QList<Transfer*> &t)
         }
     }
 
-    emit transfersRemovedEvent(handlers);
+    Q_EMIT transfersRemovedEvent(handlers);
 }
 
 TransferModelItem * TransferTreeModel::itemFromTransferHandler(TransferHandler * handler)
@@ -384,7 +384,7 @@ GroupModelItem * TransferTreeModel::itemFromTransferGroupHandler(TransferGroupHa
     
 ModelItem * TransferTreeModel::itemFromHandler(Handler * handler)
 {
-    TransferHandler *transfer = qobject_cast<TransferHandler*>(handler);
+    auto *transfer = qobject_cast<TransferHandler*>(handler);
     if (transfer) {
         return itemFromTransferHandler(transfer);
     }
@@ -433,7 +433,7 @@ void TransferTreeModel::moveTransfer(Transfer * transfer, TransferGroup * destGr
     itemFromHandler(destGroup->handler())->insertRow(destGroup->indexOf(transfer), items);
     
     if (!sameGroup)
-        emit transferMovedEvent(transfer->handler(), destGroup->handler());
+        Q_EMIT transferMovedEvent(transfer->handler(), destGroup->handler());
 
     KGet::selectionModel()->clearSelection();
 }
@@ -575,7 +575,7 @@ QStringList TransferTreeModel::mimeTypes() const
 
 QMimeData * TransferTreeModel::mimeData(const QModelIndexList &indexes) const
 {
-    ItemMimeData *mimeData = new ItemMimeData();
+    auto *mimeData = new ItemMimeData();
 
     QModelIndexList sortedIndexes = indexes;
     std::sort(sortedIndexes.begin(), sortedIndexes.end(), [](const QModelIndex &a, const QModelIndex &b) { return b < a; });
@@ -597,7 +597,7 @@ bool TransferTreeModel::dropMimeData(const QMimeData * mdata, Qt::DropAction act
     if (action == Qt::IgnoreAction)
         return true;
 
-    const ItemMimeData *itemData = qobject_cast<const ItemMimeData*>(mdata);
+    const auto *itemData = qobject_cast<const ItemMimeData*>(mdata);
     if (!itemData) {
         qCWarning(KGET_DEBUG) << "Unsupported mime data dropped.";
         return false;
@@ -715,7 +715,7 @@ void TransferTreeModel::timerEvent(QTimerEvent *event)
             ModelItem * item = itemFromHandler(group);
             Transfer::ChangesFlags changesFlags = transfer->changesFlags();
 
-            emit transfer->transferChangedEvent(transfer, changesFlags);
+            Q_EMIT transfer->transferChangedEvent(transfer, changesFlags);
             
             int row = group->indexOf(transfer);
 
@@ -744,7 +744,7 @@ void TransferTreeModel::timerEvent(QTimerEvent *event)
     }
 
     if(!updatedTransfers.isEmpty())
-        emit transfersChangedEvent(updatedTransfers);
+        Q_EMIT transfersChangedEvent(updatedTransfers);
 
     foreach(TransferGroupHandler * group, m_changedGroups)
     {
@@ -752,7 +752,7 @@ void TransferTreeModel::timerEvent(QTimerEvent *event)
         {
             TransferGroup::ChangesFlags changesFlags = group->changesFlags();
 
-            emit group->groupChangedEvent(group, changesFlags);
+            Q_EMIT group->groupChangedEvent(group, changesFlags);
             
             int row = itemFromHandler(group)->row();
             
@@ -774,7 +774,7 @@ void TransferTreeModel::timerEvent(QTimerEvent *event)
                     QStandardItem *groupItem = itemFromHandler(group);
                     dynamic_cast<ModelItem*>(invisibleRootItem()->child(groupItem->row(), i))->emitDataChanged();
                     //QModelIndex index = createIndex(m_transferGroups.indexOf(group->m_group), i, group);
-                    //emit dataChanged(index,index);
+                    //Q_EMIT dataChanged(index,index);
                 }
             }*/
 
@@ -784,7 +784,7 @@ void TransferTreeModel::timerEvent(QTimerEvent *event)
     }
 
     if(!updatedGroups.isEmpty())
-        emit groupsChangedEvent(updatedGroups);
+        Q_EMIT groupsChangedEvent(updatedGroups);
 
     m_changedTransfers.clear();
     m_changedGroups.clear();
