@@ -21,10 +21,10 @@ class BTSettingsWidget : public KCModule, public Ui::BTSettingsWidget
     public:
         BTSettingsWidget(QWidget * parent = nullptr, const QVariantList &args = QVariantList());
 
-    public slots:
-        virtual void load() override;
-        virtual void save() override;
-        virtual void defaults() override;
+    public Q_SLOTS:
+        void load() override;
+        void save() override;
+        void defaults() override;
 };
 
 #endif
