@@ -23,6 +23,8 @@
 #include "core/signature.h"
 
 #include "kget_debug.h"
+
+#include <kwidgetsaddons_version.h>
 #include <KIO/DeleteJob>
 #include <KIO/RenameDialog>
 #include <KLocalizedString>
@@ -212,9 +214,20 @@ void AbstractMetalink::slotVerified(bool isVerified)
 
         if (brokenFiles.count())
         {
-            if (KMessageBox::warningYesNoCancelList(nullptr,
-                i18n("The download could not be verified, do you want to repair (if repairing does not work the download would be restarted) it?"),
-                     brokenFiles) == KMessageBox::Yes) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (KMessageBox::warningTwoActionsList(nullptr,
+#else
+            if (KMessageBox::warningYesNoList(nullptr,
+#endif
+                    i18n("The download could not be verified, do you want to repair (if repairing does not work the download would be restarted) it?"),
+                    brokenFiles, QString(),
+                    KGuiItem(i18nc("@action:button", "Repair")),
+                    KGuiItem(i18nc("@action:button", "Ignore"), QStringLiteral("dialog-cancel")))
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                == KMessageBox::PrimaryAction) {
+#else
+                == KMessageBox::Yes) {
+#endif
                 if (repair()) {
                     return;
                 }
