@@ -83,8 +83,8 @@ QMenu * ContextMenu::createTransferContextMenu(TransferHandler* handler, QWidget
         menuActions.setItemListProperties(KFileItemListProperties(items));
         menuActions.setParentWidget(parent);
 
-        menuActions.addServiceActionsTo(popup);
-        menuActions.addOpenWithActionsTo(popup, "DesktopEntryName != 'kget'");
+        menuActions.addActionsTo(popup, KFileItemActions::MenuActionSource::Services);
+        menuActions.insertOpenWithActionsTo(nullptr, popup, QStringList("org.kde.kget"));
 
         // TODO : seems like the popup menu has to be showed while the KonqMenuActions instance exists ?
         popup->exec(QCursor::pos());
