@@ -10,9 +10,9 @@
 #include "transferhistorycategorizedview.h"
 #include "ui/history/transferhistoryitemdelegate.h"
 
-#include <kcategorizedsortfilterproxymodel.h>
-#include <kcategorizedview.h>
-#include <kcategorydrawer.h>
+#include <KCategorizedSortFilterProxyModel>
+#include <KCategorizedView>
+#include <KCategoryDrawer>
 #include <QDebug>
 
 #include <QGridLayout>
@@ -26,13 +26,13 @@ TransferHistoryCategorizedView::TransferHistoryCategorizedView(QWidget *parent)
     : QWidget(parent)
 {
     // the widget layout
-    QGridLayout *layout = new QGridLayout();
+    auto *layout = new QGridLayout(this);
 
     // initialize the model
     m_model = new QStandardItemModel();
 
     // the kcategoryizedview list
-    TransferHistoryItemDelegate *item_delegate = new TransferHistoryItemDelegate(this);
+    auto *item_delegate = new TransferHistoryItemDelegate(this);
     m_view = new KCategorizedView(this);
     m_drawer = new KCategoryDrawer(m_view);
     m_view->setCategoryDrawer(m_drawer);
@@ -54,7 +54,6 @@ TransferHistoryCategorizedView::TransferHistoryCategorizedView(QWidget *parent)
 
     connect(item_delegate, &TransferHistoryItemDelegate::deletedTransfer, this, &TransferHistoryCategorizedView::deletedTransfer);
     connect(m_view, &KCategorizedView::doubleClicked, this, &TransferHistoryCategorizedView::doubleClicked);
-    setLayout(layout);
 }
 
 TransferHistoryCategorizedView::~TransferHistoryCategorizedView()
@@ -63,7 +62,7 @@ TransferHistoryCategorizedView::~TransferHistoryCategorizedView()
 
 void TransferHistoryCategorizedView::addData(const QDate &date, const QString &url, const QString &dest, int size)
 {
-    QStandardItem *item = new QStandardItem(url);
+    auto *item = new QStandardItem(url);
     item->setData(QVariant(size), TransferHistoryCategorizedDelegate::RoleSize);
     item->setData(QVariant(url), TransferHistoryCategorizedDelegate::RoleUrl);
     item->setData(QVariant(dest), TransferHistoryCategorizedDelegate::RoleDest);
